@@ -63,9 +63,9 @@ end
 
 
 require "English"
-require "rss/utils"
-require "rss/converter"
-require "rss/xml-stylesheet"
+require_relative "utils"
+require_relative "converter"
+require_relative "xml-stylesheet"
 
 module RSS
 
@@ -374,12 +374,12 @@ EOC
       end
     end
 
-    def yes_clean_other_attr_reader(*attrs)
+    def explicit_clean_other_attr_reader(*attrs)
       attrs.each do |attr|
         module_eval(<<-EOC, __FILE__, __LINE__ + 1)
           attr_reader(:#{attr})
           def #{attr}?
-            YesCleanOther.parse(@#{attr})
+            ExplicitCleanOther.parse(@#{attr})
           end
         EOC
       end
@@ -544,7 +544,7 @@ EOC
 EOC
     end
 
-    def yes_clean_other_writer(name, disp_name=name)
+    def explicit_clean_other_writer(name, disp_name=name)
       module_eval(<<-EOC, __FILE__, __LINE__ + 1)
         def #{name}=(value)
           value = (value ? "yes" : "no") if [true, false].include?(value)
@@ -596,11 +596,10 @@ EOC
 
       def #{accessor_name}=(*args)
         receiver = self.class.name
-        warn("Warning:\#{caller.first.sub(/:in `.*'\z/, '')}: " \
-             "Don't use `\#{receiver}\##{accessor_name} = XXX'/" \
+        warn("Don't use `\#{receiver}\##{accessor_name} = XXX'/" \
              "`\#{receiver}\#set_#{accessor_name}(XXX)'. " \
              "Those APIs are not sense of Ruby. " \
-             "Use `\#{receiver}\##{plural_name} << XXX' instead of them.")
+             "Use `\#{receiver}\##{plural_name} << XXX' instead of them.", uplevel: 1)
         if args.size == 1
           @#{accessor_name}.push(args[0])
         else
@@ -763,8 +762,8 @@ EOC
           text_type_writer name, disp_name
         when :content
           content_writer name, disp_name
-        when :yes_clean_other
-          yes_clean_other_writer name, disp_name
+        when :explicit_clean_other
+          explicit_clean_other_writer name, disp_name
         when :yes_other
           yes_other_writer name, disp_name
         when :csv
@@ -782,8 +781,8 @@ EOC
           inherit_convert_attr_reader name
         when :uri
           uri_convert_attr_reader name
-        when :yes_clean_other
-          yes_clean_other_attr_reader name
+        when :explicit_clean_other
+          explicit_clean_other_attr_reader name
         when :yes_other
           yes_other_attr_reader name
         when :csv
